#
# Copyright 2015-2019 Andrey Galkin <andrey@futoin.org>
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from ..util.log import *

__all__ = ('LogMixIn')


class LogMixIn(object):
    __slots__ = ()

    def _info(self, msg, label=None):
        if label:  # for backward compatibility
            infoLabel(label, msg)
        else:
            info(msg)

    def _infoLabel(self, label, msg):
        infoLabel(label, msg)

    def _warn(self, msg):
        warn(msg)

    def _errorExit(self, msg):
        errorExit(msg)
