#
# Copyright 2019 Andrey Galkin <andrey@futoin.org>
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from ..runenvtool import RunEnvTool


class erlangTool(RunEnvTool):
    """
    Erlang OTP.

Home: https://www.erlang.org/
"""

    __slots__ = ()

    def _installTool(self, env):
        install = self._install

        install.dpkg(
            env, 'erlang-solutions',
            'https://packages.erlang-solutions.com/erlang-solutions_1.0_all.deb',
            True)

        install.generic(['erlang'])

    def uninstallTool(self, env):
        pass

    def initEnv(self, env):
        super(erlangTool, self).initEnv(env, 'erl')
